@@ -3,4 +3,4 @@
 from .nscomponent import BaseNSComponent, NSComponentName
 from .attribute import ItemElementAttribute
 from .element import ItemElementMeta, ItemElement, MultipleElements
-from .item import ItemMeta, BaseFeedItem
+from .item import ItemMeta, FeedItem, ExtendableItem
